@@ -102,7 +102,7 @@
 	    (pars (matching-substring rest 2)))
 	(if (string-match "^[ :]*\\(.*\\)" pars)
 	    (irchat-w-insert irchat-200-buffer
-			     (format "*** Serv %s (%s) ==> %s" 
+			     (format "*** Serv %s (%s) ==> %s\n" 
 				     prefix class (matching-substring pars 1)))
 	  (if (string-match 
 	       "[ :]*\\([0-9]*\\)*C \\([0-9]*\\)*S[ :]*\\(.*\\)"
@@ -158,11 +158,9 @@
 	    (rcvem (matching-substring rest 6))
 	    (rcveb (matching-substring rest 7))
 	    (open (matching-substring rest 8)))
-	(irchat-w-insert irchat-200-buffer link)
-	(indent-to-column 35)
 	(irchat-w-insert irchat-200-buffer 
-			 (format "*** %s: %5s%7s%10s%7s%10s %s\n"
-				 prefix sendq sendm sendb rcvem rcveb open)))
+	 (format "%-35s*** %s: %5s%7s%10s%7s%10s %s\n" link
+		 prefix sendq sendm sendb rcvem rcveb open)))
     (message "IRCHAT: Strance 211 message")))
 
 
@@ -221,7 +219,9 @@
 
 (defun irchat-handle-216-msg (prefix rest)
   "216 RPL_STATSKLINE k2 K *.hut.fi * tsh 0 -1"
-  (if (string-match "[^ ]* K \\([^ ]*\\) \\(.\\) \\([^ ]*\\) 0 -1" rest)
+  (if (or
+       (string-match "[^ ]* K \\([^ ]*\\) \\(.\\) \\([^ ]*\\) 0 -1" rest)
+       (string-match "[^ ]* K \\([^ ]*\\) \\([^ ]*\\) \\([^ ]*\\) 0 [:]*-1" rest))
       (let ((host (matching-substring rest 1))
 	    (pass (matching-substring rest 2))
 	    (user (matching-substring rest 3)))
