@@ -287,8 +287,6 @@ with specified user."
   (if (string= "" kill-nickname-var)
       (let ((buf (current-buffer))
 	    (buffer-read-only))
-	(set-buffer irchat-Dialogue-buffer)
-	(goto-char (point-max))
 	(irchat-w-insert irchat-D-buffer "*** Currently ignored people:")
 	(let ((mylist irchat-kill-nickname))
 	  (while mylist
