@@ -586,14 +586,9 @@ One is for entering commands and text, the other displays the IRC dialogue."
     (let* ((obuf (current-buffer))
 	   (bufintern (intern (format "%s" (irchat-get-buffer-create buffer)) 
 			      irchat-obarray))
-	   (narrow (get bufintern 'narrow))
-	   (frozen (get bufintern 'frozen))
+	   (frozen (irchat-frozen buffer))
 	   (spoint nil))
       (set-buffer (get-buffer buffer))
-      (if narrow
-	  (progn
-	    (setq spoint (point))
-	    (widen)))
       (goto-char (point-max))
       (if buffer-read-only
 	  (setq buffer-read-only nil))
@@ -618,10 +613,10 @@ One is for entering commands and text, the other displays the IRC dialogue."
     (let* ((obuf (current-buffer))
 	   (bufintern) 
 	   (nbuf (get-buffer buffer))
-	   (narrow)
 	   (frozen)
 	   (spoint nil)
-	   (oldwstart nil))
+	   (oldwstart nil)
+	   (oldwpoint nil))
 
       (if (not nbuf)
 	  (save-excursion
@@ -629,8 +624,11 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	    (set-buffer nbuf)
 	    (irchat-Dialogue-mode)))
 
+      (if (get-buffer-window obuf)
+	  (progn
+	    (setq oldwstart (window-start (get-buffer-window obuf))
+		  oldwpoint (window-point (get-buffer-window obuf)))))
       (setq bufintern (intern (format "%s" nbuf) irchat-obarray))
-      (setq narrow (get bufintern 'narrow))
       (setq frozen (irchat-frozen nbuf))
       (set-buffer nbuf)
       ;;
@@ -639,39 +637,34 @@ One is for entering commands and text, the other displays the IRC dialogue."
       ;; and point-max a constant, not the distance between
       ;; point and mark, seesh mta Fri Jan  3 12:43:01 EET 1992
       ;;
-      (setq oldwstart (window-start (selected-window)))
       (setq spoint (point))
-      (if narrow
-	  (progn
-	    (widen)))
       (goto-char (point-max))
       (if buffer-read-only
 	  (setq buffer-read-only nil))
-      (if (not (irchat-is-message-ignored string))
+      (if (not (irchat-is-message-ignored string nbuf))
 	  (insert string))
       (setq buffer-read-only t)
       (goto-char spoint)
-      (if narrow
+      (let ((win (get-buffer-window (get-buffer buffer))))
+	(if (and (not (not win))
+		 (not frozen)
+		 (not (pos-visible-in-window-p (point-max) win)))
+	    (progn
+	      (goto-char (point-max))
+	      (vertical-motion (- (+ 1 (if (not irchat-scroll-step)
+					   (/ (window-height win) 2)
+					 irchat-scroll-step))
+				  (window-height win))
+			       win)
+	      (set-window-start win (point))
+	      (goto-char (point-max)))))
+      (set-buffer obuf)
+      (if (and frozen (get-buffer-window obuf) (equal obuf nbuf))
 	  (progn
-	    (narrow-to-region (car narrow)
-			      (car (cdr narrow)))
-	    (goto-char spoint))
-	(let ((win (get-buffer-window (get-buffer buffer))))
-	  (if (and (not (not win))
-		   (not frozen)
-		   (not (pos-visible-in-window-p (point-max) win)))
-	      (progn
-		(goto-char (point-max))
-		(vertical-motion (- (+ 1 (if (not irchat-scroll-step)
-					     (/ (window-height win) 2)
-					   irchat-scroll-step))
-				    (window-height win))
-				 win)
-		(set-window-start win (point))
-		(goto-char (point-max))))))
-      (if (and frozen (equal nbuf obuf))
-	  (set-window-start (selected-window) oldwstart))
-      (set-buffer obuf))
+	    (set-window-start (get-buffer-window obuf) oldwstart)
+	    (set-window-point (get-buffer-window obuf) oldwpoint)
+	    (goto-char oldwpoint)
+	    )))
     nil))
 
 
@@ -732,11 +725,13 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	  (setq buflist (cdr buflist)))
 	(set-buffer obuf))))
 
-(defun irchat-is-message-ignored (string)
+(defun irchat-is-message-ignored (string buffer)
   (let ((mylist irchat-ignore-list)
 	(found nil)
 	(case-fold-search t))
     (catch 'ignore
+      (if (member buffer irchat-no-ignore-buffers)
+	  (throw 'ignore t))
       (while mylist
 	(let ((msg nil) 
 	      (str nil)
