@@ -181,10 +181,7 @@
 (defun irchat-msg-from-ignored (prefix rest)
   (save-excursion
     (let ((buf (current-buffer)))
-      (set-buffer irchat-IGNORED-buffer)
-      (goto-char (point-max))
       (irchat-w-insert irchat-I-buffer (format "%s::%s\n" prefix rest))
-      (set-buffer buf)
       t)))
 
 ;;;
